@@ -23,6 +23,15 @@ class LazyQueryset(object):
         self._has_cache = False
         self._cache = []
 
+    def count(self):
+        """
+        """
+
+        if not self._has_cache:
+            self._generate_cache()
+
+        return len(self._cache)
+
     def _generate_cache(self):
         """
         """
@@ -44,10 +53,7 @@ class LazyQueryset(object):
         """
         """
 
-        if not self._has_cache:
-            self._generate_cache()
-
-        return len(self._cache)
+        return self.count()
 
 
 class IndexQueryset(LazyQueryset):
@@ -226,6 +232,12 @@ class CollectionQueryset(LazyQueryset):
 
         return self
 
+    def get(self, **kwargs):
+        """
+        """
+
+        return self._manager.get(**kwargs)
+
     def all(self):
         """
         """
@@ -331,6 +343,8 @@ class CollectionQueryset(LazyQueryset):
 
 class CollectionModelManager(object):
 
+    queryset = CollectionQueryset
+
     def __init__(self, cls):
         """
         """
@@ -381,7 +395,7 @@ class CollectionModelManager(object):
         """
         """
 
-        queryset = CollectionQueryset(manager=self)
+        queryset = self.queryset(manager=self)
         return queryset.all()
 
     def filter(self, **kwargs):
@@ -391,7 +405,7 @@ class CollectionModelManager(object):
         :return:
         """
 
-        queryset = CollectionQueryset(manager=self)
+        queryset = self.queryset(manager=self)
         return queryset.all().filter(**kwargs)
 
     def exclude(self, **kwargs):
@@ -401,7 +415,7 @@ class CollectionModelManager(object):
         :return:
         """
 
-        queryset = CollectionQueryset(manager=self)
+        queryset = self.queryset(manager=self)
         return queryset.all().exclude(**kwargs)
 
     def limit(self, count, start=-1):
@@ -410,7 +424,7 @@ class CollectionModelManager(object):
         :return:
         """
 
-        queryset = CollectionQueryset(manager=self)
+        queryset = self.queryset(manager=self)
         return queryset.all().limit(count=count, start=start)
 
     def search_by_index(self, index, **kwargs):
@@ -530,6 +544,49 @@ class CollectionModel(object):
         def __init__(self):
             self._fields = {}
 
+    @classmethod
+    def get_all_fields(cls, class_obj=None, fields=None):
+        """
+            TODO: This needs to be properly used
+        """
+
+        def return_fields(obj):
+
+            internal_fields = fields
+            if internal_fields is None:
+                internal_fields = {}
+
+            for attribute in dir(obj):
+
+                try:
+                    attr_val = getattr(obj, attribute)
+                    attr_cls = attr_val.__class__
+
+                    # If it is a model field, call on init
+                    if issubclass(attr_cls, ModelField):
+                        internal_fields[attribute] = attr_val
+                except:
+                    pass
+
+            return internal_fields
+
+        if class_obj is None:
+            class_obj = cls
+
+            fields = return_fields(class_obj)
+            for parent_class in cls.__bases__:
+                parent_fields = cls.get_all_fields(parent_class, fields)
+                for field_name, field_value in parent_fields.items():
+                    if not field_name in fields:
+                        fields[field_name] = field_value
+
+            return fields
+
+        else:
+            if not isinstance(class_obj, CollectionModel):
+                return fields
+
+
     @classmethod
     def get_collection_fields_dict(cls):
         """
@@ -539,12 +596,15 @@ class CollectionModel(object):
 
         for attribute in dir(cls):
 
-            attr_val = getattr(cls, attribute)
-            attr_cls = attr_val.__class__
+            try:
+                attr_val = getattr(cls, attribute)
+                attr_cls = attr_val.__class__
 
-            # If it is a model field, call on init
-            if issubclass(attr_cls, ModelField):
-                fields[attribute] = attr_val
+                # If it is a model field, call on init
+                if issubclass(attr_cls, ModelField):
+                    fields[attribute] = attr_val
+            except:
+                pass
 
         model_fields = cls._model_meta_data._fields
         for field_key in  model_fields:
@@ -562,12 +622,15 @@ class CollectionModel(object):
 
         for attribute in dir(cls):
 
-            attr_val = getattr(cls, attribute)
-            attr_cls = attr_val.__class__
+            try:
+                attr_val = getattr(cls, attribute)
+                attr_cls = attr_val.__class__
 
-            # If it is a model field, call on init
-            if issubclass(attr_cls, ModelField):
-                fields.append(attr_val)
+                # If it is a model field, call on init
+                if issubclass(attr_cls, ModelField):
+                    fields.append(attr_val)
+            except:
+                pass
 
         model_fields = cls._model_meta_data._fields
         for field_key in  model_fields:
@@ -585,12 +648,16 @@ class CollectionModel(object):
 
         for attribute in dir(cls):
 
-            attr_val = getattr(cls, attribute)
-            attr_cls = attr_val.__class__
+            try:
+                attr_val = getattr(cls, attribute)
+                attr_cls = attr_val.__class__
 
-            # If it is a model field, call on init
-            if issubclass(attr_cls, BaseIndex):
-                index_list[attribute] = attr_val
+                # If it is a model field, call on init
+                if issubclass(attr_cls, BaseIndex):
+                    index_list[attribute] = attr_val
+
+            except:
+                pass
 
         return index_list
 
@@ -623,12 +690,19 @@ class CollectionModel(object):
         except:
             pass # This is the case if init was called more than once
 
+        cls._default_manager = cls.objects
+
         # Create meta data for collection
         cls._model_meta_data = cls.MetaDataObj()
 
         if hasattr(cls, 'Meta'):
             cls._meta = cls.Meta()
             cls._meta.model_name = name
+            cls._meta.object_name = name
+
+            # Giving other classes the chance to extend the meta data on init
+            if hasattr(cls, 'extend_meta_data'):
+                cls.extend_meta_data(cls, cls._meta)
 
         # Go through all fields
         fields_dict = cls.get_collection_fields_dict()
@@ -766,11 +840,14 @@ class CollectionModel(object):
 
         for attribute in dir(self):
 
-            attr_val = getattr(self, attribute)
-            attr_cls = attr_val.__class__
+            try:
+                attr_val = getattr(self, attribute)
+                attr_cls = attr_val.__class__
 
-            if issubclass(attr_cls, ModelField):
-                fields[attribute] = attr_val
+                if issubclass(attr_cls, ModelField):
+                    fields[attribute] = attr_val
+            except:
+                pass
 
         model_fields = self.__class__._model_meta_data._fields
         for field_key in  model_fields:
@@ -779,6 +856,12 @@ class CollectionModel(object):
 
         return fields
 
+    def serializable_value(self, attr):
+        """
+        """
+
+        return getattr(self, attr)
+
     def __getattribute__(self, item):
         """
         """
@@ -790,7 +873,7 @@ class CollectionModel(object):
             return self._instance_meta_data._fields[item].get()
         elif item == 'id':
             return self.document.id
-        elif item == 'key':
+        elif item == 'key' or item == 'pk':
             return self.document.key
         else:
             return super(CollectionModel, self).__getattribute__(item)
